==> hyades.ies.sdk.3.0.0_20040525_1708.zip: org/eclipse/hyades/execution/harness/XMLExecutionDataProcessor.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.execution.harness;
import java.net.InetAddress;
import java.util.HashMap;

import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.hyades.internal.execution.local.common.DataServerListener;
import org.eclipse.hyades.internal.execution.local.control.Agent;
import org.eclipse.hyades.internal.execution.local.control.Process;
import org.eclipse.hyades.loaders.common.ExecutionContext;
import org.eclipse.hyades.loaders.hierarchy.IgnoredXMLFragmentLoader;
import org.eclipse.hyades.loaders.util.InvalidXMLException;
import org.eclipse.hyades.loaders.util.XMLLoader;
import org.eclipse.hyades.models.common.facades.behavioral.ITest;
import org.eclipse.hyades.models.common.testprofile.TPFTestSuite;
import org.eclipse.hyades.models.hierarchy.TRCMonitor;
/**
 * @author amathur
 * @author ejessee
 *
 * To change the template for this generated type comment go to
 * Window>Preferences>Java>Code Generation>Code and Comments
 */
public class XMLExecutionDataProcessor
	extends XMLLoader
	implements DataServerListener, IExecutionHarnessDataProcessor {
		
	private final String START_TAG = "<EXECUTION>";
	private final String XML_VERSION_TAG = "<?xml version=\"1.0\"?>";
	public static final String IID = "org.eclipse.hyades.execution.harness.XMLExecutionDataProcessor";
	private ITest test = null;
	private Agent controlAgent = null;
	private Process process = null;
	private static HashMap contextMap = new HashMap();
	
	private String hostName;
	private String executionResultName;
	private String executionResultLocation;
	private String portNumber;
	/**
	 * XMLDataProcessor constructor comment.
	 */
	public XMLExecutionDataProcessor() 
	{
	 
		super((TRCMonitor) null);
		
	}
	
	
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.loaders.util.XMLLoader#isIgnoredElement()
	 */
	protected boolean isIgnoredElement() {
		if (startDocument) {
			if (currentElementName == null) {
				return true;
			}
			if (currentElementName.equals("EXECUTION")) {
				return true;
			}
			else {
				startDocument = false;
			}
		}
		return false;
	}
	
	protected boolean isValidTag(String buf) {
		if (buf.startsWith(START_TAG) || buf.startsWith(XML_VERSION_TAG))
			return false;
		else
			return true;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.internal.execution.local.common.DataServerListener#dataServerExited()
	 */
	public void dataServerExited() 
	{		
		// Clean up the ExecutionContext
		final ExecutionContext eContext = (ExecutionContext) context.getCustomData().get(ExecutionContext.root);
		synchronized(eContext)
		{
			//if we are the last agent out, then we'll clean up the context.
			if(eContext.decrementAgentCount()==0)
			{
				//here we have a problem.  Because sometimes, there are still message streaming when the 
				//dataserver exits, we cannot clean up yet.  WE need to synchronized this.  
				//for now, we will just put in this less than optimal wait.  I think 3 seconds should be adequate time.
				Thread contextCleaner = new Thread()
				{
				    public void run()
				    {
						try 
						{
							sleep(3000);
						} 
						catch (InterruptedException e) {}
						
						eContext.cleanUp();
						contextMap.remove(executionResultLocation+"/"+executionResultName);
					}
				
				
				};
				contextCleaner.setName("context cleanup");
				contextCleaner.start();
			}
		}
		cleanUp();
		
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.core.IDataProcessor#incommingData(byte[], int, java.net.InetAddress)
	 */
	public void incommingData(byte[] buffer, int length, InetAddress peer) {
		try {
			super.loadEvent(buffer, length);
		}
		catch (InvalidXMLException e) {
		}
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.core.IDataProcessor#incommingData(char[], int, java.net.InetAddress)
	 */
	public void incommingData(char[] buffer, int length, InetAddress peer) {
		byte[] newBuffer = new byte[length];
		for (int i = 0; i < length; i++) {
			newBuffer[i] = (byte) buffer[i];
		}
		this.incommingData(newBuffer, newBuffer.length, peer);
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.core.IDataProcessor#invalidDataType(byte[], int, java.net.InetAddress)
	 */
	public void invalidDataType(byte[] data, int length, InetAddress peer) {
		// No use of this method	
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.core.IDataProcessor#waitingForData()
	 */
	public void waitingForData() 
	{
		// No use of this method		
	}
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.harness.TestExecutionHarnessDataProcessor#init(org.eclipse.hyades.models.common.facades.behavioral.ITest, org.eclipse.hyades.models.common.configuration.CFGLocation, java.lang.String, java.lang.String)
	 */
	public void init()
	{
			//		Specify the ignore for an unexpected event
			 defaultLoader =  new IgnoredXMLFragmentLoader();
		
			
			 if(!(getTest() instanceof TPFTestSuite))
			 	return;
			 	
		     // Create an execution context & add it to the Hierarchy Context					
			// This will create the root execution result/history for this execution
			 ExecutionContext eContext = (ExecutionContext)contextMap.get(executionResultLocation+"/"+executionResultName);
			 if(eContext==null)
			 {
			 	TPFTestSuite suite = (TPFTestSuite)getTest();
			 	eContext = new ExecutionContext(suite, suite.getId(), executionResultLocation, executionResultName);
			 	contextMap.put(executionResultLocation+"/"+executionResultName,eContext);
			 }
			 	
			 eContext.incrementAgentCount();
			 // Add the ExecutionContext to the HierarchyContext
			 context.getCustomData().put(ExecutionContext.root, eContext);

	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.harness.IExecutionDataProcessor#getConfigElement()
	 */
	public IConfigurationElement getConfigElement()
	{
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.harness.IExecutionDataProcessor#getID()
	 */
	public String getID()
	{
		return IID;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.harness.IExecutionDataProcessor#getName()
	 */
	public String getName()
	{
		return getClass().getName();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.harness.IExecutionDataProcessor#setConfigElement(org.eclipse.core.runtime.IConfigurationElement)
	 */
	public void setConfigElement(IConfigurationElement theElement)
	{

	}

	/**
	 * @return
	 */
	public ITest getTest()
	{
		return test;
	}

		
	/**
	 * @return
	 */
	public Agent getControlAgent()
	{
		return controlAgent;
	}

	/**
	 * @param agent
	 */
	public void setControlAgent(Agent agent)
	{
		controlAgent = agent;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.harness.IExecutionDataProcessor#setInitData(java.lang.String, java.lang.String, java.lang.String, java.lang.String)
	 */
	public void setInitData(
		ITest test,
		String hostName,
		String executionResultName,
		String executionResultLocation,
		String portNumber)
	{
		this.test=test;
		this.hostName = hostName;
		this.executionResultName = executionResultName;
		this.executionResultLocation = executionResultLocation;
		this.portNumber = portNumber;
		

	}

	/**
	 * @return
	 */
	public Process getProcess()
	{
		return process;
	}

	/**
	 * @param process
	 */
	public void setProcess(Process process)
	{
		this.process = process;
	}

}

==> hyades.ies.sdk.3.0.1.1_20041012_1600.zip: org/eclipse/hyades/execution/harness/XMLExecutionDataProcessor.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.execution.harness;
import java.net.InetAddress;
import java.util.HashMap;

import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.hyades.internal.execution.local.common.DataServerListener;
import org.eclipse.hyades.internal.execution.local.control.Agent;
import org.eclipse.hyades.internal.execution.local.control.Process;
import org.eclipse.hyades.loaders.common.ExecutionContext;
import org.eclipse.hyades.loaders.hierarchy.IgnoredXMLFragmentLoader;
import org.eclipse.hyades.loaders.util.InvalidXMLException;
import org.eclipse.hyades.loaders.util.XMLLoader;
import org.eclipse.hyades.models.common.facades.behavioral.ITest;
import org.eclipse.hyades.models.common.testprofile.TPFTestSuite;
import org.eclipse.hyades.models.hierarchy.TRCMonitor;
/**
 * @author amathur
 * @author ejessee
 *
 * To change the template for this generated type comment go to
 * Window>Preferences>Java>Code Generation>Code and Comments
 */
public class XMLExecutionDataProcessor
	extends XMLLoader
	implements DataServerListener, IExecutionHarnessDataProcessor2 {
		
	private final String START_TAG = "<EXECUTION>";
	private final String XML_VERSION_TAG = "<?xml version=\"1.0\"?>";
	public static final String IID = "org.eclipse.hyades.execution.harness.XMLExecutionDataProcessor";
	private ITest test = null;
	private Agent controlAgent = null;
	private Process process = null;
	private static HashMap contextMap = new HashMap();
	
	private String hostName;
	private String executionResultName;
	private boolean overrideExistingExcResult = false;
	private String executionResultLocation;
	private String portNumber;
	/**
	 * XMLDataProcessor constructor comment.
	 */
	public XMLExecutionDataProcessor() 
	{
	 
		super((TRCMonitor) null);
		
	}
	
	
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.loaders.util.XMLLoader#isIgnoredElement()
	 */
	protected boolean isIgnoredElement() {
		if (startDocument) {
			if (currentElementName == null) {
				return true;
			}
			if (currentElementName.equals("EXECUTION")) {
				return true;
			}
			else {
				startDocument = false;
			}
		}
		return false;
	}
	
	protected boolean isValidTag(String buf) {
		if (buf.startsWith(START_TAG) || buf.startsWith(XML_VERSION_TAG))
			return false;
		else
			return true;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.internal.execution.local.common.DataServerListener#dataServerExited()
	 */
	public void dataServerExited() 
	{		
		// Clean up the ExecutionContext
		final ExecutionContext eContext = (ExecutionContext) context.getCustomData().get(ExecutionContext.root);
		synchronized(eContext)
		{
			//if we are the last agent out, then we'll clean up the context.
			if(eContext.decrementAgentCount()==0)
			{
				//here we have a problem.  Because sometimes, there are still message streaming when the 
				//dataserver exits, we cannot clean up yet.  WE need to synchronized this.  
				//for now, we will just put in this less than optimal wait.  I think 3 seconds should be adequate time.
				Thread contextCleaner = new Thread()
				{
				    public void run()
				    {
						try 
						{
							sleep(3000);
						} 
						catch (InterruptedException e) {}
						
						eContext.cleanUp();
						contextMap.remove(executionResultLocation+"/"+executionResultName);
					}
				
				
				};
				contextCleaner.setName("context cleanup");
				contextCleaner.start();
			}
		}
		cleanUp();
		
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.core.IDataProcessor#incommingData(byte[], int, java.net.InetAddress)
	 */
	public void incommingData(byte[] buffer, int length, InetAddress peer) {
		try {
			super.loadEvent(buffer, length);
		}
		catch (InvalidXMLException e) {
		}
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.core.IDataProcessor#incommingData(char[], int, java.net.InetAddress)
	 */
	public void incommingData(char[] buffer, int length, InetAddress peer) {
		byte[] newBuffer = new byte[length];
		for (int i = 0; i < length; i++) {
			newBuffer[i] = (byte) buffer[i];
		}
		this.incommingData(newBuffer, newBuffer.length, peer);
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.core.IDataProcessor#invalidDataType(byte[], int, java.net.InetAddress)
	 */
	public void invalidDataType(byte[] data, int length, InetAddress peer) {
		// No use of this method	
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.core.IDataProcessor#waitingForData()
	 */
	public void waitingForData() 
	{
		// No use of this method		
	}
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.harness.TestExecutionHarnessDataProcessor#init(org.eclipse.hyades.models.common.facades.behavioral.ITest, org.eclipse.hyades.models.common.configuration.CFGLocation, java.lang.String, java.lang.String)
	 */
	public void init()
	{
			//		Specify the ignore for an unexpected event
			 defaultLoader =  new IgnoredXMLFragmentLoader();
		
			
			 if(!(getTest() instanceof TPFTestSuite))
			 	return;
			 	
		     // Create an execution context & add it to the Hierarchy Context					
			// This will create the root execution result/history for this execution
			 ExecutionContext eContext = (ExecutionContext)contextMap.get(executionResultLocation+"/"+executionResultName);
			 if(eContext==null)
			 {
			 	TPFTestSuite suite = (TPFTestSuite)getTest();
			 	eContext = new ExecutionContext(suite, suite.getId(), executionResultLocation, executionResultName, overrideExistingExcResult);
			 	contextMap.put(executionResultLocation+"/"+executionResultName,eContext);
			 }
			 	
			 eContext.incrementAgentCount();
			 // Add the ExecutionContext to the HierarchyContext
			 context.getCustomData().put(ExecutionContext.root, eContext);

	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.harness.IExecutionDataProcessor#getConfigElement()
	 */
	public IConfigurationElement getConfigElement()
	{
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.harness.IExecutionDataProcessor#getID()
	 */
	public String getID()
	{
		return IID;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.harness.IExecutionDataProcessor#getName()
	 */
	public String getName()
	{
		return getClass().getName();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.harness.IExecutionDataProcessor#setConfigElement(org.eclipse.core.runtime.IConfigurationElement)
	 */
	public void setConfigElement(IConfigurationElement theElement)
	{

	}

	/**
	 * @return
	 */
	public ITest getTest()
	{
		return test;
	}

		
	/**
	 * @return
	 */
	public Agent getControlAgent()
	{
		return controlAgent;
	}

	/**
	 * @param agent
	 */
	public void setControlAgent(Agent agent)
	{
		controlAgent = agent;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.harness.IExecutionDataProcessor#setInitData(java.lang.String, java.lang.String, java.lang.String, java.lang.String)
	 */
	public void setInitData(
		ITest test,
		String hostName,
		String executionResultName,
		String executionResultLocation,
		String portNumber)
	{
		this.setInitData(test, hostName, executionResultName, executionResultLocation, false, portNumber);
		

	}
		
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.execution.harness.IExecutionHarnessDataProcessor#setInitData(org.eclipse.hyades.models.common.facades.behavioral.ITest, java.lang.String, java.lang.String, boolean, java.lang.String, java.lang.String)
	 */
	public void setInitData(ITest theTest, String hostName,
			String executionResultName, String executionResultLocation, 
			boolean overwriteExistingResults, String portNumber) 
	{
		this.test= theTest;
		this.hostName = hostName;
		this.executionResultName = executionResultName;
		this.overrideExistingExcResult = overwriteExistingResults;
		this.executionResultLocation = executionResultLocation;
		this.portNumber = portNumber;

	}
	
	/**
	 * @return
	 */
	public Process getProcess()
	{
		return process;
	}

	/**
	 * @param process
	 */
	public void setProcess(Process process)
	{
		this.process = process;
	}

}
